@@ -99,7 +99,7 @@ __copyright__ = """pyRad - a wheel type command menu.
 ### Constants ###
 
 #: The PyRad version identifier
-__version__ = "0.6.1"
+__version__ = "0.6.2"
 appName = "pyRad"
 
 ### Commandline handling ###
@@ -162,13 +162,19 @@ class KUniqueCaller(KUniqueApplication):
 
     def quit(self):
         """Quit the program: close the rad, then quit."""
-        self.close()
-        del self.rad
+        try:
+            self.close()
+            del self.rad
+        except AttributeError: 
+            # quit called on the commandline, so the rad does not
+            # exist for this instance.
+            pass
         super(KUniqueCaller, self).quit()
 
     def close(self):
         """Slot for closing the rad."""
         self.rad.close()
+            
 
     def newInstance(self):
         """Get a new instance -> in reality only check if there's already an instance and tell the GUI to run."""
