@@ -5,12 +5,14 @@
 
 ### Imports ###
 
+#import objgraph# find memleaks
+
 # First the basic python stuff
 # for starting programs
-from subprocess import Popen
+import subprocess
 
 # basics, currently only for prefix
-import sys
+import sys, os
 # For circles
 from math import sin, cos, pi
 # and parsing a command string into words for Popen
@@ -112,11 +114,13 @@ Flattr me? :)""")
 
     def openShortcutConfig(self):
         """Open the Keyboard Shortcut config dialog"""
-        Popen(["kcmshell4", "keys"])
+        self.parent().processes.add(
+            subprocess.Popen(["kcmshell4", "keys"], stdout=subprocess.PIPE, stderr=subprocess.PIPE))
 
     def openGesturesConfig(self):
         """Open the Keyboard Shortcut config dialog"""
-        Popen(["kcmshell4", "khotkeys"])
+        self.parent().processes.add(
+            subprocess.Popen(["kcmshell4", "khotkeys"], stdout=subprocess.PIPE, stderr=subprocess.PIPE))
 
     def openFlattrUrl(self):
         """Open the flattr Url for the pyrad."""
@@ -256,6 +260,9 @@ class Rad(QWidget):
         # resize
         self.resize(WINDOW_WIDTH, WINDOW_HEIGHT)
 
+        # add a devnull file to send process output.
+        self.devnull = open(os.devnull, "wb")
+
         # Add a circle-list for all items
         self.circle = []
 
@@ -335,32 +342,41 @@ class Rad(QWidget):
         if self.editor.main.isVisible():
             return None
         
+        #print objgraph.show_growth()
+
         # Get the position
         pos = event.pos()
 
+        clicked = None
         for i in self.circle[:]:
             if self.isInside(pos, i):
-                # If pyRad didn't reach a final action, we stop here.
-                if event.button() == Qt.LeftButton:
-                    if self.labelClicked(i) is None:
-                        break # TODO: Check if we can use return None instead
-                elif event.button() == Qt.RightButton and i != self.circle[0]:
-                    self.editLabel(i)
-                    break
-                elif event.button() == Qt.RightButton and i == self.circle[0]:# and i.action is None: # only in the top wheel.
-		    # TODO: right-click on the middle item should show the options. 
-		    # currently we just don't edit it. 
-                    self.editor_config.config()
-                    break
-		elif event.button() == Qt.MidButton:
-                    self.addLabelAfter(i)
-                    break
-                else: # other buttons are ignored
-                    break
+                clicked = i
 
-                # Otherwise we can hide the pyRad
+        if not clicked:
+            # Otherwise we can hide the pyRad
+            self.hide()
+
+        # If pyRad didn't reach a final action, we stop here.
+        if event.button() == Qt.LeftButton:
+            if self.labelClicked(clicked) is None:
+                return # TODO: Check if we can use return None instead
+            else: 
                 self.hide()
-                
+        elif event.button() == Qt.RightButton and clicked != self.circle[0]:
+            self.editLabel(clicked)
+            return
+        elif event.button() == Qt.RightButton and clicked == self.circle[0]:# and i.action is None: # only in the top wheel.
+            # TODO: right-click on the middle item should show the options. 
+            # currently we just don't edit it. 
+            self.editor_config.config()
+            return
+        elif event.button() == Qt.MidButton:
+            self.addLabelAfter(clicked)
+            return
+        else: # other buttons are ignored
+            return
+
+            
     def keyReleaseEvent(self, event):
         """Select items via keyboard."""
         # Debug: Don't react, if an edit dialog is open.
@@ -431,13 +447,13 @@ class Rad(QWidget):
         # and the circle stays visible.
         if label.action is not None:
             try:
-                Popen(split_action(label.action))
+                subprocess.Popen(split_action(label.action), 
+                                 stdout=self.devnull, 
+                                 stderr=self.devnull)
                 return True
             except:
                 return None
 
-
-
     def isInside(self, point, thing):
         """Check, if the point is inside the thing."""
         if point.x() > thing.x() and point.x() < thing.x() + thing.width() and point.y() > thing.y() and point.y() < thing.y() + thing.height():
@@ -459,7 +475,15 @@ class Rad(QWidget):
         # First remove the previous items
         for label in self.circle[:]:
             label.hide()
+            label.close()
+            label.clear()
             label.destroy()
+            #print dir(label)
+            #print label.parent().children()
+        #print objgraph.show_growth()
+        #if self.circle:
+        #    objgraph.show_backrefs(self.circle[:], filename="graph.png")
+        
 
         # Then create the circle list
         self.circle = self.items_to_circle(items)
